==> dcmtk-docs-3.6.9-3-x86_64.pkg.tar.zst: usr/share/doc/dcmtk/html/search/all_d.js <==
var searchData=
[
  ['j591_5f89zr_0',['J591_89Zr',['../classCID4021__PETRadiopharmaceutical.html#ab9d7447a00beb29c38a42b5f9d3bd9d7a77fc860119c3b01e677b932106ea8bb4',1,'CID4021_PETRadiopharmaceutical']]],
  ['jawregion_1',['JawRegion',['../classCID4031__CommonAnatomicRegion.html#ad209b02f1f43434075b427a599dcb7c0a25849dad408eba654e9ab5d593df6587',1,'CID4031_CommonAnatomicRegion']]],
  ['jejunum_2',['Jejunum',['../classCID4031__CommonAnatomicRegion.html#ad209b02f1f43434075b427a599dcb7c0a8c007dc3caaf3665b662afac7abc1eb1',1,'CID4031_CommonAnatomicRegion']]],
  ['jfifparameters_3',['JfifParameters',['../structJfifParameters.html',1,'']]],
  ['jhuff_5ftbl_4',['JHUFF_TBL',['../structJHUFF__TBL.html',1,'']]],
  ['jls_5fcompressionbitdepth_5',['JLS_CompressionBitDepth',['../djlsutil_8h.html#a3e719a60a7376a5f8fe6990a281529bf',1,'djlsutil.h']]],
  ['jls_5fplanarconfiguration_6',['JLS_PlanarConfiguration',['../djlsutil_8h.html#ad4415126d88484211a203c8777c492a5',1,'djlsutil.h']]],
  ['jls_5fuidcreation_7',['JLS_UIDCreation',['../djlsutil_8h.html#a74ecbf1ac6868c1afb1734c9f0717605',1,'djlsutil.h']]],
  ['jlscodec_8',['JlsCodec',['../classJlsCodec.html',1,'']]],
  ['jlscodecfactory_9',['JlsCodecFactory',['../classJlsCodecFactory.html',1,'']]],
  ['jlscontext_10',['JlsContext',['../structJlsContext.html',1,'']]],
  ['jlscustomparameters_11',['JlsCustomParameters',['../structJlsCustomParameters.html',1,'']]],
  ['jlsexception_12',['JlsException',['../classJlsException.html',1,'']]],
  ['jlsinputstream_13',['JLSInputStream',['../classJLSInputStream.html',1,'']]],
  ['jlsoutputstream_14',['JLSOutputStream',['../classJLSOutputStream.html',1,'']]],
  ['jlsparameters_15',['JlsParameters',['../structJlsParameters.html',1,'']]],
  ['jlsrect_16',['JlsRect',['../structJlsRect.html',1,'']]],
  ['jndmax_17',['JNDMax',['../classDiGSDFunction.html#a77525eb6243a130687f895b069f43eb1',1,'DiGSDFunction']]],
  ['jndmin_18',['JNDMin',['../classDiGSDFunction.html#a7afbdbe0a1e5f701509becb5db946d08',1,'DiGSDFunction']]],
  ['job_19',['dcmpsprt: Read DICOM images and presentation states and render print job',['../dcmpsprt.html',1,'']]],
  ['joboptionexpectsparameters_20',['jobOptionExpectsParameters',['../classMdfConsoleEngine.html#a9e4707f2034c46d055b0a334473e596e',1,'MdfConsoleEngine']]],
  ['jobs_21',['jobs',['../classMdfConsoleEngine.html#a12e0c853f631aec0222a4876f50b6d4e',1,'MdfConsoleEngine']]],
  ['join_22',['join',['../classOFConsole.html#ac538fdcbdee695e0dd00de08a04edb38',1,'OFConsole::join()'],['../classOFThread.html#afd2ae504286cd0767e05583c1b575012',1,'OFThread::join()']]],
  ['joined_23',['joined',['../classOFConsole.html#a417e52d098cc1001981b60551ce338cd',1,'OFConsole']]],
  ['jointaverageofglcm_24',['JointAverageOfGLCM',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a9dd906022b6a248158a80eeabad70efc',1,'CID218_QuantitativeImageFeature']]],
  ['jointentropyofglcm_25',['JointEntropyOfGLCM',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2acd7d1113eab50c59b49c7f5eaf5559e4',1,'CID218_QuantitativeImageFeature']]],
  ['jointmaximumofglcm_26',['JointMaximumOfGLCM',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a2c105bf3db09f8bdea0a1c4d4826d691',1,'CID218_QuantitativeImageFeature']]],
  ['jointvarianceofglcm_27',['JointVarianceOfGLCM',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2ae9ff27637b208df197bbdbb2a56dfa80',1,'CID218_QuantitativeImageFeature']]],
  ['jp2ksupport_28',['JP2KSupport',['../classDicomDirInterface.html#ac5f992adc1c4b122b8f5c714d663c21c',1,'DicomDirInterface']]],
  ['jpeg_20compressed_20dicom_20file_29',['dcmdjpeg: Decode JPEG-compressed DICOM file',['../dcmdjpeg.html',1,'']]],
  ['jpeg_20encoding_20options_30',['JPEG encoding options',['../dcmcjpeg.html#dcmcjpeg_JPEG_encoding_options',1,'']]],
  ['jpeg_20input_20plugin_31',['JPEG Input Plugin',['../img2dcm.html#img2dcm_jpeg_input_plugin',1,'']]],
  ['jpeg_20ls_20compressed_20dicom_20file_32',['dcmdjpls: Decode JPEG-LS compressed DICOM file',['../dcmdjpls.html',1,'']]],
  ['jpeg_20ls_20encoding_20options_33',['JPEG-LS encoding options',['../dcmcjpls.html#dcmcjpls_JPEG_LS_encoding_options',1,'']]],
  ['jpeg_20ls_20input_20plugin_34',['JPEG-LS Input Plugin',['../img2dcm.html#img2dcm_jpegls_input_plugin',1,'']]],
  ['jpeg_20ls_20transfer_20syntax_35',['dcmcjpls: Encode DICOM file to JPEG-LS transfer syntax',['../dcmcjpls.html',1,'']]],
  ['jpeg_20or_20bmp_36',['dcmj2pnm: Convert DICOM images to PGM/PPM, PNG, TIFF, JPEG or BMP',['../dcmj2pnm.html',1,'']]],
  ['jpeg_20transfer_20syntax_37',['dcmcjpeg: Encode DICOM file to JPEG transfer syntax',['../dcmcjpeg.html',1,'']]],
  ['jpeg_5fc_5fcodec_38',['jpeg_c_codec',['../structjpeg__c__codec.html',1,'']]],
  ['jpeg_5fc_5fmain_5fcontroller_39',['jpeg_c_main_controller',['../structjpeg__c__main__controller.html',1,'']]],
  ['jpeg_5fc_5fprep_5fcontroller_40',['jpeg_c_prep_controller',['../structjpeg__c__prep__controller.html',1,'']]],
  ['jpeg_5fcolor_5fconverter_41',['jpeg_color_converter',['../structjpeg__color__converter.html',1,'']]],
  ['jpeg_5fcolor_5fdeconverter_42',['jpeg_color_deconverter',['../structjpeg__color__deconverter.html',1,'']]],
  ['jpeg_5fcolor_5fquantizer_43',['jpeg_color_quantizer',['../structjpeg__color__quantizer.html',1,'']]],
  ['jpeg_5fcommon_5fstruct_44',['jpeg_common_struct',['../structjpeg__common__struct.html',1,'']]],
  ['jpeg_5fcomp_5fmaster_45',['jpeg_comp_master',['../structjpeg__comp__master.html',1,'']]],
  ['jpeg_5fcomponent_5finfo_46',['jpeg_component_info',['../structjpeg__component__info.html',1,'']]],
  ['jpeg_5fcompress_5fstruct_47',['jpeg_compress_struct',['../structjpeg__compress__struct.html',1,'']]],
  ['jpeg_5fd_5fcodec_48',['jpeg_d_codec',['../structjpeg__d__codec.html',1,'']]],
  ['jpeg_5fd_5fmain_5fcontroller_49',['jpeg_d_main_controller',['../structjpeg__d__main__controller.html',1,'']]],
  ['jpeg_5fd_5fpost_5fcontroller_50',['jpeg_d_post_controller',['../structjpeg__d__post__controller.html',1,'']]],
  ['jpeg_5fdecomp_5fmaster_51',['jpeg_decomp_master',['../structjpeg__decomp__master.html',1,'']]],
  ['jpeg_5fdecompress_5fstruct_52',['jpeg_decompress_struct',['../structjpeg__decompress__struct.html',1,'']]],
  ['jpeg_5fdestination_5fmgr_53',['jpeg_destination_mgr',['../structjpeg__destination__mgr.html',1,'']]],
  ['jpeg_5fdownsampler_54',['jpeg_downsampler',['../structjpeg__downsampler.html',1,'']]],
  ['jpeg_5ferror_5fmgr_55',['jpeg_error_mgr',['../structjpeg__error__mgr.html',1,'']]],
  ['jpeg_5ferror_5fmgr_2emsg_5fparm_56',['jpeg_error_mgr.msg_parm',['../unionjpeg__error__mgr_8msg__parm.html',1,'']]],
  ['jpeg_5finput_5fcontroller_57',['jpeg_input_controller',['../structjpeg__input__controller.html',1,'']]],
  ['jpeg_5flossless_5fc_5fcodec_58',['jpeg_lossless_c_codec',['../structjpeg__lossless__c__codec.html',1,'']]],
  ['jpeg_5flossless_5fd_5fcodec_59',['jpeg_lossless_d_codec',['../structjpeg__lossless__d__codec.html',1,'']]],
  ['jpeg_5flossy_5fc_5fcodec_60',['jpeg_lossy_c_codec',['../structjpeg__lossy__c__codec.html',1,'']]],
  ['jpeg_5flossy_5fd_5fcodec_61',['jpeg_lossy_d_codec',['../structjpeg__lossy__d__codec.html',1,'']]],
  ['jpeg_5fmarker_5freader_62',['jpeg_marker_reader',['../structjpeg__marker__reader.html',1,'']]],
  ['jpeg_5fmarker_5fstruct_63',['jpeg_marker_struct',['../structjpeg__marker__struct.html',1,'']]],
  ['jpeg_5fmarker_5fwriter_64',['jpeg_marker_writer',['../structjpeg__marker__writer.html',1,'']]],
  ['jpeg_5fmemory_5fmgr_65',['jpeg_memory_mgr',['../structjpeg__memory__mgr.html',1,'']]],
  ['jpeg_5fprogress_5fmgr_66',['jpeg_progress_mgr',['../structjpeg__progress__mgr.html',1,'']]],
  ['jpeg_5fscan_5finfo_67',['jpeg_scan_info',['../structjpeg__scan__info.html',1,'']]],
  ['jpeg_5fsource_5fmgr_68',['jpeg_source_mgr',['../structjpeg__source__mgr.html',1,'']]],
  ['jpeg_5fupsampler_69',['jpeg_upsampler',['../structjpeg__upsampler.html',1,'']]],
  ['jpegfile_70',['jpegFile',['../classI2DJpegSource.html#a9e3a6d61dc654ecfeba3a0c2cc4d14a9',1,'I2DJpegSource']]],
  ['jpegfilemapentry_71',['JPEGFileMapEntry',['../structJPEGFileMapEntry.html',1,'']]],
  ['jpegmarkertostring_72',['jpegMarkerToString',['../classI2DJpegSource.html#ab3e84d34ff13b7d291c1f38ec75844d9',1,'I2DJpegSource']]],
  ['jpegprocess12_73',['JPEGProcess12',['../classDcmXfer.html#abce15108d88835f3fc786c3d9db25c2e',1,'DcmXfer']]],
  ['jpegprocess8_74',['JPEGProcess8',['../classDcmXfer.html#a4d383c6a9a4d18c9fd46984bb7ca406a',1,'DcmXfer']]],
  ['jpegsegment_75',['JpegSegment',['../classJpegSegment.html',1,'']]],
  ['jpegsupport_76',['JPEGSupport',['../classDicomDirInterface.html#a716adef74e3d8c021f84a3963d57599e',1,'DicomDirInterface']]],
  ['jpls_5freset_5f_77',['jpls_reset_',['../classDJLSCodecParameter.html#a8fb38fda5fb4dee20d9c94e950c666fb',1,'DJLSCodecParameter']]],
  ['jpls_5ft1_5f_78',['jpls_t1_',['../classDJLSCodecParameter.html#aa791843b98f1fb2616d20ceba290313d',1,'DJLSCodecParameter']]],
  ['jpls_5ft2_5f_79',['jpls_t2_',['../classDJLSCodecParameter.html#a203be04b4d58f0beb1429dcfb313ce88',1,'DJLSCodecParameter']]],
  ['jpls_5ft3_5f_80',['jpls_t3_',['../classDJLSCodecParameter.html#a813d6f16ff517b886d9265fde505f35a',1,'DJLSCodecParameter']]],
  ['jplsinterleavemode_5f_81',['jplsInterleaveMode_',['../classDJLSCodecParameter.html#a20617d0205123124d2e9d67d349eb2d2',1,'DJLSCodecParameter']]],
  ['jquant_5ftbl_82',['JQUANT_TBL',['../structJQUANT__TBL.html',1,'']]],
  ['jsampbuffer_83',['jsampBuffer',['../classDJDecompressIJG12Bit.html#a43405eb932c630bd9fa16a5a791edeca',1,'DJDecompressIJG12Bit::jsampBuffer'],['../classDJDecompressIJG16Bit.html#ac1e098f47cb1654e47c09d2c87178204',1,'DJDecompressIJG16Bit::jsampBuffer'],['../classDJDecompressIJG8Bit.html#a5abea7048a002b2c6f970206b15df872',1,'DJDecompressIJG8Bit::jsampBuffer']]],
  ['json_84',['dcm2json: Convert DICOM file and data set to JSON',['../dcm2json.html',1,'']]],
  ['json_20format_85',['JSON Format',['../dcm2json.html#dcm2json_json_format',1,'']]]
];

==> dcmtk-docs-3.7.0-1-x86_64.pkg.tar.zst: usr/share/doc/dcmtk/html/search/all_d.js <==
var searchData=
[
  ['j591_5f89zr_0',['J591_89Zr',['../classCID4021__PETRadiopharmaceutical.html#ab9d7447a00beb29c38a42b5f9d3bd9d7a77fc860119c3b01e677b932106ea8bb4',1,'CID4021_PETRadiopharmaceutical']]],
  ['jawregion_1',['JawRegion',['../classCID4031__CommonAnatomicRegion.html#ad209b02f1f43434075b427a599dcb7c0a25849dad408eba654e9ab5d593df6587',1,'CID4031_CommonAnatomicRegion']]],
  ['jejunum_2',['Jejunum',['../classCID4031__CommonAnatomicRegion.html#ad209b02f1f43434075b427a599dcb7c0a8c007dc3caaf3665b662afac7abc1eb1',1,'CID4031_CommonAnatomicRegion']]],
  ['jfifparameters_3',['JfifParameters',['../structJfifParameters.html',1,'']]],
  ['jhuff_5ftbl_4',['JHUFF_TBL',['../structJHUFF__TBL.html',1,'']]],
  ['jls_5fcompressionbitdepth_5',['JLS_CompressionBitDepth',['../djlsutil_8h.html#a3e719a60a7376a5f8fe6990a281529bf',1,'djlsutil.h']]],
  ['jls_5fplanarconfiguration_6',['JLS_PlanarConfiguration',['../djlsutil_8h.html#ad4415126d88484211a203c8777c492a5',1,'djlsutil.h']]],
  ['jls_5fuidcreation_7',['JLS_UIDCreation',['../djlsutil_8h.html#a74ecbf1ac6868c1afb1734c9f0717605',1,'djlsutil.h']]],
  ['jlscodec_8',['JlsCodec',['../classJlsCodec.html',1,'']]],
  ['jlscodecfactory_9',['JlsCodecFactory',['../classJlsCodecFactory.html',1,'']]],
  ['jlscontext_10',['JlsContext',['../structJlsContext.html',1,'']]],
  ['jlscustomparameters_11',['JlsCustomParameters',['../structJlsCustomParameters.html',1,'']]],
  ['jlsexception_12',['JlsException',['../classJlsException.html',1,'']]],
  ['jlsinputstream_13',['JLSInputStream',['../classJLSInputStream.html',1,'']]],
  ['jlsoutputstream_14',['JLSOutputStream',['../classJLSOutputStream.html',1,'']]],
  ['jlsparameters_15',['JlsParameters',['../structJlsParameters.html',1,'']]],
  ['jlsrect_16',['JlsRect',['../structJlsRect.html',1,'']]],
  ['jndmax_17',['JNDMax',['../classDiGSDFunction.html#a77525eb6243a130687f895b069f43eb1',1,'DiGSDFunction']]],
  ['jndmin_18',['JNDMin',['../classDiGSDFunction.html#a7afbdbe0a1e5f701509becb5db946d08',1,'DiGSDFunction']]],
  ['job_19',['dcmpsprt: Read DICOM images and presentation states and render print job',['../dcmpsprt.html',1,'']]],
  ['joboptionexpectsparameters_20',['jobOptionExpectsParameters',['../classMdfConsoleEngine.html#a9e4707f2034c46d055b0a334473e596e',1,'MdfConsoleEngine']]],
  ['jobs_21',['jobs',['../classMdfConsoleEngine.html#a12e0c853f631aec0222a4876f50b6d4e',1,'MdfConsoleEngine']]],
  ['join_22',['join',['../classOFConsole.html#ac538fdcbdee695e0dd00de08a04edb38',1,'OFConsole::join()'],['../classOFThread.html#afd2ae504286cd0767e05583c1b575012',1,'OFThread::join()']]],
  ['joined_23',['joined',['../classOFConsole.html#a417e52d098cc1001981b60551ce338cd',1,'OFConsole']]],
  ['jointaverageofglcm_24',['JointAverageOfGLCM',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a9dd906022b6a248158a80eeabad70efc',1,'CID218_QuantitativeImageFeature']]],
  ['jointentropyofglcm_25',['JointEntropyOfGLCM',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2acd7d1113eab50c59b49c7f5eaf5559e4',1,'CID218_QuantitativeImageFeature']]],
  ['jointmaximumofglcm_26',['JointMaximumOfGLCM',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2a2c105bf3db09f8bdea0a1c4d4826d691',1,'CID218_QuantitativeImageFeature']]],
  ['jointvarianceofglcm_27',['JointVarianceOfGLCM',['../classCID218__QuantitativeImageFeature.html#a947a24c74fbe0c5573e5130474d83bb2ae9ff27637b208df197bbdbb2a56dfa80',1,'CID218_QuantitativeImageFeature']]],
  ['jp2ksupport_28',['JP2KSupport',['../classDicomDirInterface.html#ac5f992adc1c4b122b8f5c714d663c21c',1,'DicomDirInterface']]],
  ['jpeg_20compressed_20dicom_20file_29',['dcmdjpeg: Decode JPEG-compressed DICOM file',['../dcmdjpeg.html',1,'']]],
  ['jpeg_20encoding_20options_30',['JPEG encoding options',['../dcmcjpeg.html#dcmcjpeg_JPEG_encoding_options',1,'']]],
  ['jpeg_20input_20plugin_31',['JPEG Input Plugin',['../img2dcm.html#img2dcm_jpeg_input_plugin',1,'']]],
  ['jpeg_20ls_20compressed_20dicom_20file_32',['dcmdjpls: Decode JPEG-LS compressed DICOM file',['../dcmdjpls.html',1,'']]],
  ['jpeg_20ls_20encoding_20options_33',['JPEG-LS encoding options',['../dcmcjpls.html#dcmcjpls_JPEG_LS_encoding_options',1,'']]],
  ['jpeg_20ls_20input_20plugin_34',['JPEG-LS Input Plugin',['../img2dcm.html#img2dcm_jpegls_input_plugin',1,'']]],
  ['jpeg_20ls_20transfer_20syntax_35',['dcmcjpls: Encode DICOM file to JPEG-LS transfer syntax',['../dcmcjpls.html',1,'']]],
  ['jpeg_20or_20bmp_36',['dcmj2pnm: Convert DICOM images to PGM/PPM, PNG, TIFF, JPEG or BMP',['../dcmj2pnm.html',1,'']]],
  ['jpeg_20transfer_20syntax_37',['dcmcjpeg: Encode DICOM file to JPEG transfer syntax',['../dcmcjpeg.html',1,'']]],
  ['jpeg_5fc_5fcodec_38',['jpeg_c_codec',['../structjpeg__c__codec.html',1,'']]],
  ['jpeg_5fc_5fmain_5fcontroller_39',['jpeg_c_main_controller',['../structjpeg__c__main__controller.html',1,'']]],
  ['jpeg_5fc_5fprep_5fcontroller_40',['jpeg_c_prep_controller',['../structjpeg__c__prep__controller.html',1,'']]],
  ['jpeg_5fcolor_5fconverter_41',['jpeg_color_converter',['../structjpeg__color__converter.html',1,'']]],
  ['jpeg_5fcolor_5fdeconverter_42',['jpeg_color_deconverter',['../structjpeg__color__deconverter.html',1,'']]],
  ['jpeg_5fcolor_5fquantizer_43',['jpeg_color_quantizer',['../structjpeg__color__quantizer.html',1,'']]],
  ['jpeg_5fcommon_5fstruct_44',['jpeg_common_struct',['../structjpeg__common__struct.html',1,'']]],
  ['jpeg_5fcomp_5fmaster_45',['jpeg_comp_master',['../structjpeg__comp__master.html',1,'']]],
  ['jpeg_5fcomponent_5finfo_46',['jpeg_component_info',['../structjpeg__component__info.html',1,'']]],
  ['jpeg_5fcompress_5fstruct_47',['jpeg_compress_struct',['../structjpeg__compress__struct.html',1,'']]],
  ['jpeg_5fd_5fcodec_48',['jpeg_d_codec',['../structjpeg__d__codec.html',1,'']]],
  ['jpeg_5fd_5fmain_5fcontroller_49',['jpeg_d_main_controller',['../structjpeg__d__main__controller.html',1,'']]],
  ['jpeg_5fd_5fpost_5fcontroller_50',['jpeg_d_post_controller',['../structjpeg__d__post__controller.html',1,'']]],
  ['jpeg_5fdecomp_5fmaster_51',['jpeg_decomp_master',['../structjpeg__decomp__master.html',1,'']]],
  ['jpeg_5fdecompress_5fstruct_52',['jpeg_decompress_struct',['../structjpeg__decompress__struct.html',1,'']]],
  ['jpeg_5fdestination_5fmgr_53',['jpeg_destination_mgr',['../structjpeg__destination__mgr.html',1,'']]],
  ['jpeg_5fdownsampler_54',['jpeg_downsampler',['../structjpeg__downsampler.html',1,'']]],
  ['jpeg_5ferror_5fmgr_55',['jpeg_error_mgr',['../structjpeg__error__mgr.html',1,'']]],
  ['jpeg_5ferror_5fmgr_2emsg_5fparm_56',['jpeg_error_mgr.msg_parm',['../unionjpeg__error__mgr_8msg__parm.html',1,'']]],
  ['jpeg_5finput_5fcontroller_57',['jpeg_input_controller',['../structjpeg__input__controller.html',1,'']]],
  ['jpeg_5flossless_5fc_5fcodec_58',['jpeg_lossless_c_codec',['../structjpeg__lossless__c__codec.html',1,'']]],
  ['jpeg_5flossless_5fd_5fcodec_59',['jpeg_lossless_d_codec',['../structjpeg__lossless__d__codec.html',1,'']]],
  ['jpeg_5flossy_5fc_5fcodec_60',['jpeg_lossy_c_codec',['../structjpeg__lossy__c__codec.html',1,'']]],
  ['jpeg_5flossy_5fd_5fcodec_61',['jpeg_lossy_d_codec',['../structjpeg__lossy__d__codec.html',1,'']]],
  ['jpeg_5fmarker_5freader_62',['jpeg_marker_reader',['../structjpeg__marker__reader.html',1,'']]],
  ['jpeg_5fmarker_5fstruct_63',['jpeg_marker_struct',['../structjpeg__marker__struct.html',1,'']]],
  ['jpeg_5fmarker_5fwriter_64',['jpeg_marker_writer',['../structjpeg__marker__writer.html',1,'']]],
  ['jpeg_5fmemory_5fmgr_65',['jpeg_memory_mgr',['../structjpeg__memory__mgr.html',1,'']]],
  ['jpeg_5fprogress_5fmgr_66',['jpeg_progress_mgr',['../structjpeg__progress__mgr.html',1,'']]],
  ['jpeg_5fscan_5finfo_67',['jpeg_scan_info',['../structjpeg__scan__info.html',1,'']]],
  ['jpeg_5fsource_5fmgr_68',['jpeg_source_mgr',['../structjpeg__source__mgr.html',1,'']]],
  ['jpeg_5fupsampler_69',['jpeg_upsampler',['../structjpeg__upsampler.html',1,'']]],
  ['jpegfile_70',['jpegFile',['../classI2DJpegSource.html#a9e3a6d61dc654ecfeba3a0c2cc4d14a9',1,'I2DJpegSource']]],
  ['jpegfilemapentry_71',['JPEGFileMapEntry',['../structJPEGFileMapEntry.html',1,'']]],
  ['jpegmarkertostring_72',['jpegMarkerToString',['../classI2DJpegSource.html#ab3e84d34ff13b7d291c1f38ec75844d9',1,'I2DJpegSource']]],
  ['jpegprocess12_73',['JPEGProcess12',['../classDcmXfer.html#abce15108d88835f3fc786c3d9db25c2e',1,'DcmXfer']]],
  ['jpegprocess8_74',['JPEGProcess8',['../classDcmXfer.html#a4d383c6a9a4d18c9fd46984bb7ca406a',1,'DcmXfer']]],
  ['jpegsegment_75',['JpegSegment',['../classJpegSegment.html',1,'']]],
  ['jpegsupport_76',['JPEGSupport',['../classDicomDirInterface.html#a716adef74e3d8c021f84a3963d57599e',1,'DicomDirInterface']]],
  ['jpls_5freset_5f_77',['jpls_reset_',['../classDJLSCodecParameter.html#a8fb38fda5fb4dee20d9c94e950c666fb',1,'DJLSCodecParameter']]],
  ['jpls_5ft1_5f_78',['jpls_t1_',['../classDJLSCodecParameter.html#aa791843b98f1fb2616d20ceba290313d',1,'DJLSCodecParameter']]],
  ['jpls_5ft2_5f_79',['jpls_t2_',['../classDJLSCodecParameter.html#a203be04b4d58f0beb1429dcfb313ce88',1,'DJLSCodecParameter']]],
  ['jpls_5ft3_5f_80',['jpls_t3_',['../classDJLSCodecParameter.html#a813d6f16ff517b886d9265fde505f35a',1,'DJLSCodecParameter']]],
  ['jplsinterleavemode_5f_81',['jplsInterleaveMode_',['../classDJLSCodecParameter.html#a20617d0205123124d2e9d67d349eb2d2',1,'DJLSCodecParameter']]],
  ['jquant_5ftbl_82',['JQUANT_TBL',['../structJQUANT__TBL.html',1,'']]],
  ['jsampbuffer_83',['jsampBuffer',['../classDJDecompressIJG12Bit.html#a43405eb932c630bd9fa16a5a791edeca',1,'DJDecompressIJG12Bit::jsampBuffer'],['../classDJDecompressIJG16Bit.html#ac1e098f47cb1654e47c09d2c87178204',1,'DJDecompressIJG16Bit::jsampBuffer'],['../classDJDecompressIJG8Bit.html#a5abea7048a002b2c6f970206b15df872',1,'DJDecompressIJG8Bit::jsampBuffer']]],
  ['jsmn_5fparser_84',['jsmn_parser',['../structjsmn__parser.html',1,'']]],
  ['jsmntok_85',['jsmntok',['../structjsmntok.html',1,'']]],
  ['json_86',['dcm2json: Convert DICOM file and data set to JSON',['../dcm2json.html',1,'']]],
  ['json_20document_20to_20dicom_20file_20or_20data_20set_87',['json2dcm: Convert JSON document to DICOM file or data set',['../json2dcm.html',1,'']]],
  ['json_20format_88',['JSON Format',['../dcm2json.html#dcm2json_json_format',1,'']]],
  ['json2dcm_3a_20convert_20json_20document_20to_20dicom_20file_20or_20data_20set_89',['json2dcm: Convert JSON document to DICOM file or data set',['../json2dcm.html',1,'']]],
  ['jsondataset_5f_90',['jsonDataset_',['../classDcmJSONReader.html#a5d0f8b45e8adff8fa9a2da11f0261b35',1,'DcmJSONReader']]],
  ['jsondatasetlen_5f_91',['jsonDatasetLen_',['../classDcmJSONReader.html#a18d629f0f2fd0516b5c952eb9f38504e',1,'DcmJSONReader']]]
];
